package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.hw.common.core.domain.R;
import com.hw.common.core.utils.file.FileUtils;
import com.hw.system.api.RemoteFileService;
import com.hw.system.api.domain.SysFile;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBaseDeviceFiles;
import com.hw.dms.service.IDmsBaseDeviceFilesService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 设备档案信息Controller
 *
 * @author xins
 * @date 2024-01-09
 */
@RestController
@RequestMapping("/dmsFiles")
public class DmsBaseDeviceFilesController extends BaseController
{
    @Autowired
    private IDmsBaseDeviceFilesService dmsBaseDeviceFilesService;


    /**
     * 查询设备档案信息列表
     */
    @RequiresPermissions("dms:dmsFiles:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseDeviceFiles dmsBaseDeviceFiles)
    {
        startPage();
        List<DmsBaseDeviceFiles> list = dmsBaseDeviceFilesService.selectDmsBaseDeviceFilesList(dmsBaseDeviceFiles);
        return getDataTable(list);
    }

    /**
     * 导出设备档案信息列表
     */
    @RequiresPermissions("dms:dmsFiles:export")
    @Log(title = "设备档案信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseDeviceFiles dmsBaseDeviceFiles)
    {
        List<DmsBaseDeviceFiles> list = dmsBaseDeviceFilesService.selectDmsBaseDeviceFilesList(dmsBaseDeviceFiles);
        ExcelUtil<DmsBaseDeviceFiles> util = new ExcelUtil<DmsBaseDeviceFiles>(DmsBaseDeviceFiles.class);
        util.exportExcel(response, list, "设备档案信息数据");
    }

    /**
     * 获取设备档案信息详细信息
     */
    @RequiresPermissions("dms:dmsFiles:query")
    @GetMapping(value = "/{deviceFilesId}")
    public AjaxResult getInfo(@PathVariable("deviceFilesId") Long deviceFilesId)
    {
        return success(dmsBaseDeviceFilesService.selectDmsBaseDeviceFilesByDeviceFilesId(deviceFilesId));
    }

    /**
     * 新增设备档案信息
     */
    @RequiresPermissions("dms:dmsFiles:add")
    @Log(title = "设备档案信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseDeviceFiles dmsBaseDeviceFiles)
    {

        return toAjax(dmsBaseDeviceFilesService.insertDmsBaseDeviceFiles(dmsBaseDeviceFiles));
    }

    /**
     * 修改设备档案信息
     */
    @RequiresPermissions("dms:dmsFiles:edit")
    @Log(title = "设备档案信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseDeviceFiles dmsBaseDeviceFiles)
    {
        return toAjax(dmsBaseDeviceFilesService.updateDmsBaseDeviceFiles(dmsBaseDeviceFiles));
    }

    /**
     * 删除设备档案信息
     */
    @RequiresPermissions("dms:dmsFiles:remove")
    @Log(title = "设备档案信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{deviceFilesIds}")
    public AjaxResult remove(@PathVariable Long[] deviceFilesIds)
    {
        return toAjax(dmsBaseDeviceFilesService.deleteDmsBaseDeviceFilesByDeviceFilesIds(deviceFilesIds));
    }


}
