package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBaseInspectRoute;
import com.hw.dms.service.IDmsBaseInspectRouteService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 巡检线路信息Controller
 * 
 * @author Open Platform
 * @date 2024-01-16
 */
@RestController
@RequestMapping("/dmsBaseInspectRoute")
public class DmsBaseInspectRouteController extends BaseController
{
    @Autowired
    private IDmsBaseInspectRouteService dmsBaseInspectRouteService;

    /**
     * 查询巡检线路信息列表
     */
    @RequiresPermissions("dms:dmsBaseInspectRoute:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseInspectRoute dmsBaseInspectRoute)
    {
        startPage();
        List<DmsBaseInspectRoute> list = dmsBaseInspectRouteService.selectDmsBaseInspectRouteList(dmsBaseInspectRoute);
        return getDataTable(list);
    }

    /**
     * 导出巡检线路信息列表
     */
    @RequiresPermissions("dms:dmsBaseInspectRoute:export")
    @Log(title = "巡检线路信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseInspectRoute dmsBaseInspectRoute)
    {
        List<DmsBaseInspectRoute> list = dmsBaseInspectRouteService.selectDmsBaseInspectRouteList(dmsBaseInspectRoute);
        ExcelUtil<DmsBaseInspectRoute> util = new ExcelUtil<DmsBaseInspectRoute>(DmsBaseInspectRoute.class);
        util.exportExcel(response, list, "巡检线路信息数据");
    }

    /**
     * 获取巡检线路信息详细信息
     */
    @RequiresPermissions("dms:dmsBaseInspectRoute:query")
    @GetMapping(value = "/{inspectRouteId}")
    public AjaxResult getInfo(@PathVariable("inspectRouteId") Long inspectRouteId)
    {
        return success(dmsBaseInspectRouteService.selectDmsBaseInspectRouteByInspectRouteId(inspectRouteId));
    }

    /**
     * 新增巡检线路信息
     */
    @RequiresPermissions("dms:dmsBaseInspectRoute:add")
    @Log(title = "巡检线路信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseInspectRoute dmsBaseInspectRoute)
    {
        return toAjax(dmsBaseInspectRouteService.insertDmsBaseInspectRoute(dmsBaseInspectRoute));
    }

    /**
     * 修改巡检线路信息
     */
    @RequiresPermissions("dms:dmsBaseInspectRoute:edit")
    @Log(title = "巡检线路信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseInspectRoute dmsBaseInspectRoute)
    {
        return toAjax(dmsBaseInspectRouteService.updateDmsBaseInspectRoute(dmsBaseInspectRoute));
    }

    /**
     * 删除巡检线路信息
     */
    @RequiresPermissions("dms:dmsBaseInspectRoute:remove")
    @Log(title = "巡检线路信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{inspectRouteIds}")
    public AjaxResult remove(@PathVariable Long[] inspectRouteIds)
    {
        return toAjax(dmsBaseInspectRouteService.deleteDmsBaseInspectRouteByInspectRouteIds(inspectRouteIds));
    }
}
