package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBillsFaultInstance;
import com.hw.dms.service.IDmsBillsFaultInstanceService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 检修工单Controller
 * 
 * @author Open Platform
 * @date 2024-01-23
 */
@RestController
@RequestMapping("/dmsBillsFaultInstance")
public class DmsBillsFaultInstanceController extends BaseController
{
    @Autowired
    private IDmsBillsFaultInstanceService dmsBillsFaultInstanceService;

    /**
     * 查询检修工单列表
     */
    @RequiresPermissions("dms:dmsBillsFaultInstance:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBillsFaultInstance dmsBillsFaultInstance)
    {
        startPage();
        List<DmsBillsFaultInstance> list = dmsBillsFaultInstanceService.selectDmsBillsFaultInstanceList(dmsBillsFaultInstance);
        return getDataTable(list);
    }

    /**
     * 导出检修工单列表
     */
    @RequiresPermissions("dms:dmsBillsFaultInstance:export")
    @Log(title = "检修工单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBillsFaultInstance dmsBillsFaultInstance)
    {
        List<DmsBillsFaultInstance> list = dmsBillsFaultInstanceService.selectDmsBillsFaultInstanceList(dmsBillsFaultInstance);
        ExcelUtil<DmsBillsFaultInstance> util = new ExcelUtil<DmsBillsFaultInstance>(DmsBillsFaultInstance.class);
        util.exportExcel(response, list, "检修工单数据");
    }

    /**
     * 获取检修工单详细信息
     */
    @RequiresPermissions("dms:dmsBillsFaultInstance:query")
    @GetMapping(value = "/{repairInstanceId}")
    public AjaxResult getInfo(@PathVariable("repairInstanceId") Long repairInstanceId)
    {
        return success(dmsBillsFaultInstanceService.selectDmsBillsFaultInstanceByRepairInstanceId(repairInstanceId));
    }

    /**
     * 新增检修工单
     */
    @RequiresPermissions("dms:dmsBillsFaultInstance:add")
    @Log(title = "检修工单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBillsFaultInstance dmsBillsFaultInstance)
    {
        return toAjax(dmsBillsFaultInstanceService.insertDmsBillsFaultInstance(dmsBillsFaultInstance));
    }

    /**
     * 修改检修工单
     */
    @RequiresPermissions("dms:dmsBillsFaultInstance:edit")
    @Log(title = "检修工单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBillsFaultInstance dmsBillsFaultInstance)
    {
        return toAjax(dmsBillsFaultInstanceService.updateDmsBillsFaultInstance(dmsBillsFaultInstance));
    }

    /**
     * 删除检修工单
     */
    @RequiresPermissions("dms:dmsBillsFaultInstance:remove")
    @Log(title = "检修工单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{repairInstanceIds}")
    public AjaxResult remove(@PathVariable Long[] repairInstanceIds)
    {
        return toAjax(dmsBillsFaultInstanceService.deleteDmsBillsFaultInstanceByRepairInstanceIds(repairInstanceIds));
    }
}
