package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsKnowledgeLube;
import com.hw.dms.service.IDmsKnowledgeLubeService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 润滑知识库Controller
 * 
 * @author caoql
 * @date 2024-02-26
 */
@RestController
@RequestMapping("/knowledgeLube")
public class DmsKnowledgeLubeController extends BaseController
{
    @Autowired
    private IDmsKnowledgeLubeService dmsKnowledgeLubeService;

    /**
     * 查询润滑知识库列表
     */
    @RequiresPermissions("dms:knowledgeLube:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsKnowledgeLube dmsKnowledgeLube)
    {
        startPage();
        List<DmsKnowledgeLube> list = dmsKnowledgeLubeService.selectDmsKnowledgeLubeList(dmsKnowledgeLube);
        return getDataTable(list);
    }

    /**
     * 导出润滑知识库列表
     */
    @RequiresPermissions("dms:knowledgeLube:export")
    @Log(title = "润滑知识库", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsKnowledgeLube dmsKnowledgeLube)
    {
        List<DmsKnowledgeLube> list = dmsKnowledgeLubeService.selectDmsKnowledgeLubeList(dmsKnowledgeLube);
        ExcelUtil<DmsKnowledgeLube> util = new ExcelUtil<DmsKnowledgeLube>(DmsKnowledgeLube.class);
        util.exportExcel(response, list, "润滑知识库数据");
    }

    /**
     * 获取润滑知识库详细信息
     */
    @RequiresPermissions("dms:knowledgeLube:query")
    @GetMapping(value = "/{knowledgeLubeId}")
    public AjaxResult getInfo(@PathVariable("knowledgeLubeId") Long knowledgeLubeId)
    {
        return success(dmsKnowledgeLubeService.selectDmsKnowledgeLubeByKnowledgeLubeId(knowledgeLubeId));
    }

    /**
     * 新增润滑知识库
     */
    @RequiresPermissions("dms:knowledgeLube:add")
    @Log(title = "润滑知识库", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsKnowledgeLube dmsKnowledgeLube)
    {
        return toAjax(dmsKnowledgeLubeService.insertDmsKnowledgeLube(dmsKnowledgeLube));
    }

    /**
     * 修改润滑知识库
     */
    @RequiresPermissions("dms:knowledgeLube:edit")
    @Log(title = "润滑知识库", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsKnowledgeLube dmsKnowledgeLube)
    {
        return toAjax(dmsKnowledgeLubeService.updateDmsKnowledgeLube(dmsKnowledgeLube));
    }

    /**
     * 删除润滑知识库
     */
    @RequiresPermissions("dms:knowledgeLube:remove")
    @Log(title = "润滑知识库", businessType = BusinessType.DELETE)
	@DeleteMapping("/{knowledgeLubeIds}")
    public AjaxResult remove(@PathVariable Long[] knowledgeLubeIds)
    {
        return toAjax(dmsKnowledgeLubeService.deleteDmsKnowledgeLubeByKnowledgeLubeIds(knowledgeLubeIds));
    }
}
