package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsRepairInstanceActivity;
import com.hw.dms.service.IDmsRepairInstanceActivityService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 检修工单实例节点;最后一步作为检修记录Controller
 *
 * @author Open Platform
 * @date 2024-01-23
 */
@RestController
@RequestMapping("/repairInstanceActivity")
public class DmsRepairInstanceActivityController extends BaseController
{
    @Autowired
    private IDmsRepairInstanceActivityService dmsRepairInstanceActivityService;

    /**
     * 查询检修工单实例节点;最后一步作为检修记录列表
     */
    @RequiresPermissions("dms:repairInstanceActivity:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsRepairInstanceActivity dmsRepairInstanceActivity)
    {
        startPage();
        List<DmsRepairInstanceActivity> list = dmsRepairInstanceActivityService.selectDmsRepairInstanceActivityList(dmsRepairInstanceActivity);
        return getDataTable(list);
    }

    /**
     * 导出检修工单实例节点;最后一步作为检修记录列表
     */
    @RequiresPermissions("dms:repairInstanceActivity:export")
    @Log(title = "检修工单实例节点;最后一步作为检修记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsRepairInstanceActivity dmsRepairInstanceActivity)
    {
        List<DmsRepairInstanceActivity> list = dmsRepairInstanceActivityService.selectDmsRepairInstanceActivityList(dmsRepairInstanceActivity);
        ExcelUtil<DmsRepairInstanceActivity> util = new ExcelUtil<DmsRepairInstanceActivity>(DmsRepairInstanceActivity.class);
        util.exportExcel(response, list, "检修工单实例节点;最后一步作为检修记录数据");
    }

    /**
     * 获取检修工单实例节点;最后一步作为检修记录详细信息
     */
    @RequiresPermissions("dms:repairInstanceActivity:query")
    @GetMapping(value = "/{instanceActivityId}")
    public AjaxResult getInfo(@PathVariable("instanceActivityId") Long instanceActivityId)
    {
        return success(dmsRepairInstanceActivityService.selectDmsRepairInstanceActivityByInstanceActivityId(instanceActivityId));
    }

    /**
     * 新增检修工单实例节点;最后一步作为检修记录
     */
    @RequiresPermissions("dms:repairInstanceActivity:add")
    @Log(title = "检修工单实例节点;最后一步作为检修记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsRepairInstanceActivity dmsRepairInstanceActivity)
    {
        return toAjax(dmsRepairInstanceActivityService.insertDmsRepairInstanceActivity(dmsRepairInstanceActivity));
    }

    /**
     * 修改检修工单实例节点;最后一步作为检修记录
     */
    @RequiresPermissions("dms:repairInstanceActivity:edit")
    @Log(title = "检修工单实例节点;最后一步作为检修记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsRepairInstanceActivity dmsRepairInstanceActivity)
    {
        return toAjax(dmsRepairInstanceActivityService.updateDmsRepairInstanceActivity(dmsRepairInstanceActivity));
    }

    /**
     * 删除检修工单实例节点;最后一步作为检修记录
     */
    @RequiresPermissions("dms:repairInstanceActivity:remove")
    @Log(title = "检修工单实例节点;最后一步作为检修记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{instanceActivityIds}")
    public AjaxResult remove(@PathVariable Long[] instanceActivityIds)
    {
        return toAjax(dmsRepairInstanceActivityService.deleteDmsRepairInstanceActivityByInstanceActivityIds(instanceActivityIds));
    }

    /**
     * 通过维修工单实例id查询用户id
     * */
    @GetMapping("/selectUserIdByRepairInstanceId/{repairInstanceId}/userId/{userId}")
    public boolean selectUserIdByRepairInstanceId(@PathVariable("repairInstanceId") Long repairInstanceId,@PathVariable("userId") Long userId){
        return dmsRepairInstanceActivityService.selectUserIdByRepairInstanceId(repairInstanceId,userId);
    }
}
