package com.hw.dms.service.impl;

import java.util.List;
import com.hw.common.core.utils.DateUtils;
import com.hw.system.api.model.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.hw.dms.mapper.DmsBaseInspectStandardMapper;
import com.hw.dms.domain.DmsBaseInspectStandard;
import com.hw.dms.service.IDmsBaseInspectStandardService;

/**
 * 巡检标准信息Service业务层处理
 *
 * @author Open Platform
 * @date 2024-01-17
 */
@Service
public class DmsBaseInspectStandardServiceImpl implements IDmsBaseInspectStandardService
{
    @Autowired
    private DmsBaseInspectStandardMapper dmsBaseInspectStandardMapper;

    /**
     * 查询巡检标准信息
     *
     * @param inspectStandardId 巡检标准信息主键
     * @return 巡检标准信息
     */
    @Override
    public DmsBaseInspectStandard selectDmsBaseInspectStandardByInspectStandardId(Long inspectStandardId)
    {
        return dmsBaseInspectStandardMapper.selectDmsBaseInspectStandardByInspectStandardId(inspectStandardId);
    }

    /**
     * 查询巡检标准信息列表
     *
     * @param dmsBaseInspectStandard 巡检标准信息
     * @return 巡检标准信息
     */
    @Override
    public List<DmsBaseInspectStandard> selectDmsBaseInspectStandardList(DmsBaseInspectStandard dmsBaseInspectStandard)
    {
        return dmsBaseInspectStandardMapper.selectDmsBaseInspectStandardList(dmsBaseInspectStandard);
    }

    /**
     * 新增巡检标准信息
     *
     * @param dmsBaseInspectStandard 巡检标准信息
     * @return 结果
     */
    @Override
    public int insertDmsBaseInspectStandard(DmsBaseInspectStandard dmsBaseInspectStandard)
    {
        dmsBaseInspectStandard.setIsFlag("1");
        LoginUser user = new LoginUser();
        dmsBaseInspectStandard.setCreateBy(user.getUsername());
        dmsBaseInspectStandard.setCreateTime(DateUtils.getNowDate());
        return dmsBaseInspectStandardMapper.insertDmsBaseInspectStandard(dmsBaseInspectStandard);
    }

    /**
     * 修改巡检标准信息
     *
     * @param dmsBaseInspectStandard 巡检标准信息
     * @return 结果
     */
    @Override
    public int updateDmsBaseInspectStandard(DmsBaseInspectStandard dmsBaseInspectStandard)
    {
        LoginUser user = new LoginUser();
        dmsBaseInspectStandard.setUpdateBy(user.getUsername());
        dmsBaseInspectStandard.setUpdateTime(DateUtils.getNowDate());
        return dmsBaseInspectStandardMapper.updateDmsBaseInspectStandard(dmsBaseInspectStandard);
    }

    /**
     * 批量删除巡检标准信息
     *
     * @param inspectStandardIds 需要删除的巡检标准信息主键
     * @return 结果
     */
    @Override
    public int deleteDmsBaseInspectStandardByInspectStandardIds(Long[] inspectStandardIds)
    {
        return dmsBaseInspectStandardMapper.deleteDmsBaseInspectStandardByInspectStandardIds(inspectStandardIds);
    }

    /**
     * 删除巡检标准信息信息
     *
     * @param inspectStandardId 巡检标准信息主键
     * @return 结果
     */
    @Override
    public int deleteDmsBaseInspectStandardByInspectStandardId(Long inspectStandardId)
    {
        return dmsBaseInspectStandardMapper.deleteDmsBaseInspectStandardByInspectStandardId(inspectStandardId);
    }
}
