package com.hw.dms.service.impl;

import java.util.List;
import com.hw.common.core.utils.DateUtils;
import com.hw.system.api.model.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.hw.dms.mapper.DmsRecordInspectMapper;
import com.hw.dms.domain.DmsRecordInspect;
import com.hw.dms.service.IDmsRecordInspectService;

/**
 * 巡检记录Service业务层处理
 *
 * @author Open Platform
 * @date 2024-01-16
 */
@Service
public class DmsRecordInspectServiceImpl implements IDmsRecordInspectService
{
    @Autowired
    private DmsRecordInspectMapper dmsRecordInspectMapper;

    /**
     * 查询巡检记录
     *
     * @param recordInspectId 巡检记录主键
     * @return 巡检记录
     */
    @Override
    public DmsRecordInspect selectDmsRecordInspectByRecordInspectId(Long recordInspectId)
    {
        return dmsRecordInspectMapper.selectDmsRecordInspectByRecordInspectId(recordInspectId);
    }

    /**
     * 查询巡检记录列表
     *
     * @param dmsRecordInspect 巡检记录
     * @return 巡检记录
     */
    @Override
    public List<DmsRecordInspect> selectDmsRecordInspectList(DmsRecordInspect dmsRecordInspect)
    {
        return dmsRecordInspectMapper.selectDmsRecordInspectList(dmsRecordInspect);
    }

    /**
     * 新增巡检记录
     *
     * @param dmsRecordInspect 巡检记录
     * @return 结果
     */
    @Override
    public int insertDmsRecordInspect(DmsRecordInspect dmsRecordInspect)
    {
        LoginUser user = new LoginUser();
        dmsRecordInspect.setIsFlag("1");
        dmsRecordInspect.setCreateBy(user.getUsername());
        dmsRecordInspect.setCreateTime(DateUtils.getNowDate());
        return dmsRecordInspectMapper.insertDmsRecordInspect(dmsRecordInspect);
    }

    /**
     * 修改巡检记录
     *
     * @param dmsRecordInspect 巡检记录
     * @return 结果
     */
    @Override
    public int updateDmsRecordInspect(DmsRecordInspect dmsRecordInspect)
    {
        LoginUser user = new LoginUser();
        dmsRecordInspect.setUpdateBy(user.getUsername());
        dmsRecordInspect.setUpdateTime(DateUtils.getNowDate());
        return dmsRecordInspectMapper.updateDmsRecordInspect(dmsRecordInspect);
    }

    /**
     * 批量删除巡检记录
     *
     * @param recordInspectIds 需要删除的巡检记录主键
     * @return 结果
     */
    @Override
    public int deleteDmsRecordInspectByRecordInspectIds(Long[] recordInspectIds)
    {
        return dmsRecordInspectMapper.deleteDmsRecordInspectByRecordInspectIds(recordInspectIds);
    }

    /**
     * 删除巡检记录信息
     *
     * @param recordInspectId 巡检记录主键
     * @return 结果
     */
    @Override
    public int deleteDmsRecordInspectByRecordInspectId(Long recordInspectId)
    {
        return dmsRecordInspectMapper.deleteDmsRecordInspectByRecordInspectId(recordInspectId);
    }
}
