package com.hw.ems.base.service.impl;

import java.util.List;

import com.hw.common.core.utils.DateUtils;
import com.hw.ems.base.service.ISysDatasourceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.hw.ems.base.mapper.SysDatasourceMapper;
import com.hw.ems.base.domain.SysDatasource;

/**
 * 园区数据库Service业务层处理
 *
 * @author hw
 * @date 2023-04-20
 */
@Service
public class SysDatasourceServiceImpl implements ISysDatasourceService {
    @Autowired
    private SysDatasourceMapper sysDatasourceMapper;

    /**
     * 查询园区数据库
     *
     * @param id 园区数据库主键
     * @return 园区数据库
     */
    @Override
    public SysDatasource selectSysDatasourceById(String id) {
        return sysDatasourceMapper.selectSysDatasourceById(id);
    }

    /**
     * 查询园区数据库列表
     *
     * @param sysDatasource 园区数据库
     * @return 园区数据库
     */
    @Override
    public List<SysDatasource> selectSysDatasourceList(SysDatasource sysDatasource) {
        return sysDatasourceMapper.selectSysDatasourceList(sysDatasource);
    }

    /**
     * 新增园区数据库
     *
     * @param sysDatasource 园区数据库
     * @return 结果
     */
    @Override
    public int insertSysDatasource(SysDatasource sysDatasource) {
        sysDatasource.setCreateTime(DateUtils.getNowDate());
        return sysDatasourceMapper.insertSysDatasource(sysDatasource);
    }

    /**
     * 修改园区数据库
     *
     * @param sysDatasource 园区数据库
     * @return 结果
     */
    @Override
    public int updateSysDatasource(SysDatasource sysDatasource) {
        sysDatasource.setUpdateTime(DateUtils.getNowDate());
        return sysDatasourceMapper.updateSysDatasource(sysDatasource);
    }

    /**
     * 批量删除园区数据库
     *
     * @param ids 需要删除的园区数据库主键
     * @return 结果
     */
    @Override
    public int deleteSysDatasourceByIds(String[] ids) {
        return sysDatasourceMapper.deleteSysDatasourceByIds(ids);
    }

    /**
     * 删除园区数据库信息
     *
     * @param id 园区数据库主键
     * @return 结果
     */
    @Override
    public int deleteSysDatasourceById(String id) {
        return sysDatasourceMapper.deleteSysDatasourceById(id);
    }

    @Override
    public SysDatasource selectSysDatasourceByPoolName(String poolName) {
        return sysDatasourceMapper.selectSysDatasourceByPoolName(poolName);
    }

    @Override
    public SysDatasource selectSysDatasourceByCbsParkCode(String cbsParkCode) {
        return sysDatasourceMapper.selectSysDatasourceByCbsParkCode(cbsParkCode);
    }
    @Override
    public List<SysDatasource> selectSysDatasource() {
        return sysDatasourceMapper.selectSysDatasource();
    }
}
