package com.hw.mes.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.mes.domain.MesProjectInfo;
import com.hw.mes.service.IMesProjectInfoService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 项目信息Controller
 * 
 * @author Yinq
 * @date 2024-02-19
 */
@RestController
@RequestMapping("/projectinfo")
public class MesProjectInfoController extends BaseController
{
    @Autowired
    private IMesProjectInfoService mesProjectInfoService;

    /**
     * 查询项目信息列表
     */
    @RequiresPermissions("mes:projectinfo:list")
    @GetMapping("/list")
    public TableDataInfo list(MesProjectInfo mesProjectInfo)
    {
        startPage();
        List<MesProjectInfo> list = mesProjectInfoService.selectMesProjectInfoList(mesProjectInfo);
        return getDataTable(list);
    }

    /**
     * 导出项目信息列表
     */
    @RequiresPermissions("mes:projectinfo:export")
    @Log(title = "项目信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MesProjectInfo mesProjectInfo)
    {
        List<MesProjectInfo> list = mesProjectInfoService.selectMesProjectInfoList(mesProjectInfo);
        ExcelUtil<MesProjectInfo> util = new ExcelUtil<MesProjectInfo>(MesProjectInfo.class);
        util.exportExcel(response, list, "项目信息数据");
    }

    /**
     * 获取项目信息详细信息
     */
    @RequiresPermissions("mes:projectinfo:query")
    @GetMapping(value = "/{projectId}")
    public AjaxResult getInfo(@PathVariable("projectId") Long projectId)
    {
        return success(mesProjectInfoService.selectMesProjectInfoByProjectId(projectId));
    }

    /**
     * 新增项目信息
     */
    @RequiresPermissions("mes:projectinfo:add")
    @Log(title = "项目信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MesProjectInfo mesProjectInfo)
    {
        return toAjax(mesProjectInfoService.insertMesProjectInfo(mesProjectInfo));
    }

    /**
     * 修改项目信息
     */
    @RequiresPermissions("mes:projectinfo:edit")
    @Log(title = "项目信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MesProjectInfo mesProjectInfo)
    {
        return toAjax(mesProjectInfoService.updateMesProjectInfo(mesProjectInfo));
    }

    /**
     * 删除项目信息
     */
    @RequiresPermissions("mes:projectinfo:remove")
    @Log(title = "项目信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{projectIds}")
    public AjaxResult remove(@PathVariable Long[] projectIds)
    {
        return toAjax(mesProjectInfoService.deleteMesProjectInfoByProjectIds(projectIds));
    }
}
