package com.hw.mes.mapper;

import java.util.HashMap;
import java.util.List;
import com.hw.mes.domain.MesBaseRoute;
import com.hw.mes.domain.MesBaseRouteProcess;

/**
 * 工艺路线Mapper接口
 * 
 * @author Yinq
 * @date 2024-01-25
 */
public interface MesBaseRouteMapper 
{
    /**
     * 查询工艺路线
     * 
     * @param routeId 工艺路线主键
     * @return 工艺路线
     */
    public MesBaseRoute selectMesBaseRouteByRouteId(Long routeId);

    /**
     * 查询工艺路线列表
     * 
     * @param mesBaseRoute 工艺路线
     * @return 工艺路线集合
     */
    public List<MesBaseRoute> selectMesBaseRouteList(MesBaseRoute mesBaseRoute);

    /**
     * 新增工艺路线
     * 
     * @param mesBaseRoute 工艺路线
     * @return 结果
     */
    public int insertMesBaseRoute(MesBaseRoute mesBaseRoute);

    /**
     * 修改工艺路线
     * 
     * @param mesBaseRoute 工艺路线
     * @return 结果
     */
    public int updateMesBaseRoute(MesBaseRoute mesBaseRoute);

    /**
     * 删除工艺路线
     * 
     * @param routeId 工艺路线主键
     * @return 结果
     */
    public int deleteMesBaseRouteByRouteId(Long routeId);

    /**
     * 批量删除工艺路线
     * 
     * @param routeIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMesBaseRouteByRouteIds(Long[] routeIds);

    /**
     * 批量删除工艺路线组成信息
     * 
     * @param routeIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMesBaseRouteProcessByRouteIds(Long[] routeIds);
    
    /**
     * 批量新增工艺路线组成信息
     * 
     * @param mesBaseRouteProcessList 工艺路线组成信息列表
     * @return 结果
     */
    public int batchMesBaseRouteProcess(List<MesBaseRouteProcess> mesBaseRouteProcessList);
    

    /**
     * 通过工艺路线主键删除工艺路线组成信息信息
     * 
     * @param routeId 工艺路线ID
     * @return 结果
     */
    public int deleteMesBaseRouteProcessByRouteId(Long routeId);

    /**
     * 根据工艺路线ID查询工位信息
     * @param routeId
     * @return
     */
    List<HashMap<String, Object>> getStationByRouteId(Long routeId);
}
