package com.hw.mes.service.impl;

import java.util.List;
import com.hw.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.hw.mes.mapper.MesBaseProdlineInfoMapper;
import com.hw.mes.domain.MesBaseProdlineInfo;
import com.hw.mes.service.IMesBaseProdlineInfoService;

/**
 * 产线信息Service业务层处理
 * 
 * @author Yinq
 * @date 2024-01-24
 */
@Service
public class MesBaseProdlineInfoServiceImpl implements IMesBaseProdlineInfoService 
{
    @Autowired
    private MesBaseProdlineInfoMapper mesBaseProdlineInfoMapper;

    /**
     * 查询产线信息
     * 
     * @param prodlineId 产线信息主键
     * @return 产线信息
     */
    @Override
    public MesBaseProdlineInfo selectMesBaseProdlineInfoByProdlineId(Long prodlineId)
    {
        return mesBaseProdlineInfoMapper.selectMesBaseProdlineInfoByProdlineId(prodlineId);
    }

    /**
     * 查询产线信息列表
     * 
     * @param mesBaseProdlineInfo 产线信息
     * @return 产线信息
     */
    @Override
    public List<MesBaseProdlineInfo> selectMesBaseProdlineInfoList(MesBaseProdlineInfo mesBaseProdlineInfo)
    {
        return mesBaseProdlineInfoMapper.selectMesBaseProdlineInfoList(mesBaseProdlineInfo);
    }

    /**
     * 新增产线信息
     * 
     * @param mesBaseProdlineInfo 产线信息
     * @return 结果
     */
    @Override
    public int insertMesBaseProdlineInfo(MesBaseProdlineInfo mesBaseProdlineInfo)
    {
        mesBaseProdlineInfo.setCreateTime(DateUtils.getNowDate());
        return mesBaseProdlineInfoMapper.insertMesBaseProdlineInfo(mesBaseProdlineInfo);
    }

    /**
     * 修改产线信息
     * 
     * @param mesBaseProdlineInfo 产线信息
     * @return 结果
     */
    @Override
    public int updateMesBaseProdlineInfo(MesBaseProdlineInfo mesBaseProdlineInfo)
    {
        mesBaseProdlineInfo.setUpdateTime(DateUtils.getNowDate());
        return mesBaseProdlineInfoMapper.updateMesBaseProdlineInfo(mesBaseProdlineInfo);
    }

    /**
     * 批量删除产线信息
     * 
     * @param prodlineIds 需要删除的产线信息主键
     * @return 结果
     */
    @Override
    public int deleteMesBaseProdlineInfoByProdlineIds(Long[] prodlineIds)
    {
        return mesBaseProdlineInfoMapper.deleteMesBaseProdlineInfoByProdlineIds(prodlineIds);
    }

    /**
     * 删除产线信息信息
     * 
     * @param prodlineId 产线信息主键
     * @return 结果
     */
    @Override
    public int deleteMesBaseProdlineInfoByProdlineId(Long prodlineId)
    {
        return mesBaseProdlineInfoMapper.deleteMesBaseProdlineInfoByProdlineId(prodlineId);
    }
}
