package com.hw.mes.service.impl;

import java.util.List;
import com.hw.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.hw.mes.mapper.MesProjectInfoMapper;
import com.hw.mes.domain.MesProjectInfo;
import com.hw.mes.service.IMesProjectInfoService;

/**
 * 项目信息Service业务层处理
 * 
 * @author Yinq
 * @date 2024-02-19
 */
@Service
public class MesProjectInfoServiceImpl implements IMesProjectInfoService 
{
    @Autowired
    private MesProjectInfoMapper mesProjectInfoMapper;

    /**
     * 查询项目信息
     * 
     * @param projectId 项目信息主键
     * @return 项目信息
     */
    @Override
    public MesProjectInfo selectMesProjectInfoByProjectId(Long projectId)
    {
        return mesProjectInfoMapper.selectMesProjectInfoByProjectId(projectId);
    }

    /**
     * 查询项目信息列表
     * 
     * @param mesProjectInfo 项目信息
     * @return 项目信息
     */
    @Override
    public List<MesProjectInfo> selectMesProjectInfoList(MesProjectInfo mesProjectInfo)
    {
        return mesProjectInfoMapper.selectMesProjectInfoList(mesProjectInfo);
    }

    /**
     * 新增项目信息
     * 
     * @param mesProjectInfo 项目信息
     * @return 结果
     */
    @Override
    public int insertMesProjectInfo(MesProjectInfo mesProjectInfo)
    {
        mesProjectInfo.setCreateTime(DateUtils.getNowDate());
        return mesProjectInfoMapper.insertMesProjectInfo(mesProjectInfo);
    }

    /**
     * 修改项目信息
     * 
     * @param mesProjectInfo 项目信息
     * @return 结果
     */
    @Override
    public int updateMesProjectInfo(MesProjectInfo mesProjectInfo)
    {
        mesProjectInfo.setUpdateTime(DateUtils.getNowDate());
        return mesProjectInfoMapper.updateMesProjectInfo(mesProjectInfo);
    }

    /**
     * 批量删除项目信息
     * 
     * @param projectIds 需要删除的项目信息主键
     * @return 结果
     */
    @Override
    public int deleteMesProjectInfoByProjectIds(Long[] projectIds)
    {
        return mesProjectInfoMapper.deleteMesProjectInfoByProjectIds(projectIds);
    }

    /**
     * 删除项目信息信息
     * 
     * @param projectId 项目信息主键
     * @return 结果
     */
    @Override
    public int deleteMesProjectInfoByProjectId(Long projectId)
    {
        return mesProjectInfoMapper.deleteMesProjectInfoByProjectId(projectId);
    }
}
