package com.hw.qms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.qms.domain.QmsCheckResult;
import com.hw.qms.service.IQmsCheckResultService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 质检结果Controller
 * 
 * @author xins
 * @date 2024-01-23
 */
@RestController
@RequestMapping("/checkresult")
public class QmsCheckResultController extends BaseController
{
    @Autowired
    private IQmsCheckResultService qmsCheckResultService;

    /**
     * 查询质检结果列表
     */
    @RequiresPermissions("qms:checkresult:list")
    @GetMapping("/list")
    public TableDataInfo list(QmsCheckResult qmsCheckResult)
    {
        startPage();
        List<QmsCheckResult> list = qmsCheckResultService.selectQmsCheckResultList(qmsCheckResult);
        return getDataTable(list);
    }

    /**
     * 导出质检结果列表
     */
    @RequiresPermissions("qms:checkresult:export")
    @Log(title = "质检结果", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, QmsCheckResult qmsCheckResult)
    {
        List<QmsCheckResult> list = qmsCheckResultService.selectQmsCheckResultList(qmsCheckResult);
        ExcelUtil<QmsCheckResult> util = new ExcelUtil<QmsCheckResult>(QmsCheckResult.class);
        util.exportExcel(response, list, "质检结果数据");
    }

    /**
     * 获取质检结果详细信息
     */
    @RequiresPermissions("qms:checkresult:query")
    @GetMapping(value = "/{checkResultId}")
    public AjaxResult getInfo(@PathVariable("checkResultId") Long checkResultId)
    {
        return success(qmsCheckResultService.selectQmsCheckResultByCheckResultId(checkResultId));
    }

    /**
     * 新增质检结果
     */
    @RequiresPermissions("qms:checkresult:add")
    @Log(title = "质检结果", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody QmsCheckResult qmsCheckResult)
    {
        return toAjax(qmsCheckResultService.insertQmsCheckResult(qmsCheckResult));
    }

    /**
     * 修改质检结果
     */
    @RequiresPermissions("qms:checkresult:edit")
    @Log(title = "质检结果", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody QmsCheckResult qmsCheckResult)
    {
        return toAjax(qmsCheckResultService.updateQmsCheckResult(qmsCheckResult));
    }

    /**
     * 删除质检结果
     */
    @RequiresPermissions("qms:checkresult:remove")
    @Log(title = "质检结果", businessType = BusinessType.DELETE)
	@DeleteMapping("/{checkResultIds}")
    public AjaxResult remove(@PathVariable Long[] checkResultIds)
    {
        return toAjax(qmsCheckResultService.deleteQmsCheckResultByCheckResultIds(checkResultIds));
    }
}
