package com.hw.qms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.qms.domain.QmsCheckResultDetail;
import com.hw.qms.service.IQmsCheckResultDetailService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 质检结果详情Controller
 * 
 * @author xins
 * @date 2024-01-23
 */
@RestController
@RequestMapping("/checkresultdetail")
public class QmsCheckResultDetailController extends BaseController
{
    @Autowired
    private IQmsCheckResultDetailService qmsCheckResultDetailService;

    /**
     * 查询质检结果详情列表
     */
    @RequiresPermissions("qms:checkresultdetail:list")
    @GetMapping("/list")
    public TableDataInfo list(QmsCheckResultDetail qmsCheckResultDetail)
    {
        startPage();
        List<QmsCheckResultDetail> list = qmsCheckResultDetailService.selectQmsCheckResultDetailList(qmsCheckResultDetail);
        return getDataTable(list);
    }

    /**
     * 导出质检结果详情列表
     */
    @RequiresPermissions("qms:checkresultdetail:export")
    @Log(title = "质检结果详情", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, QmsCheckResultDetail qmsCheckResultDetail)
    {
        List<QmsCheckResultDetail> list = qmsCheckResultDetailService.selectQmsCheckResultDetailList(qmsCheckResultDetail);
        ExcelUtil<QmsCheckResultDetail> util = new ExcelUtil<QmsCheckResultDetail>(QmsCheckResultDetail.class);
        util.exportExcel(response, list, "质检结果详情数据");
    }

    /**
     * 获取质检结果详情详细信息
     */
    @RequiresPermissions("qms:checkresultdetail:query")
    @GetMapping(value = "/{checkResultDetailId}")
    public AjaxResult getInfo(@PathVariable("checkResultDetailId") Long checkResultDetailId)
    {
        return success(qmsCheckResultDetailService.selectQmsCheckResultDetailByCheckResultDetailId(checkResultDetailId));
    }

    /**
     * 新增质检结果详情
     */
    @RequiresPermissions("qms:checkresultdetail:add")
    @Log(title = "质检结果详情", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody QmsCheckResultDetail qmsCheckResultDetail)
    {
        return toAjax(qmsCheckResultDetailService.insertQmsCheckResultDetail(qmsCheckResultDetail));
    }

    /**
     * 修改质检结果详情
     */
    @RequiresPermissions("qms:checkresultdetail:edit")
    @Log(title = "质检结果详情", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody QmsCheckResultDetail qmsCheckResultDetail)
    {
        return toAjax(qmsCheckResultDetailService.updateQmsCheckResultDetail(qmsCheckResultDetail));
    }

    /**
     * 删除质检结果详情
     */
    @RequiresPermissions("qms:checkresultdetail:remove")
    @Log(title = "质检结果详情", businessType = BusinessType.DELETE)
	@DeleteMapping("/{checkResultDetailIds}")
    public AjaxResult remove(@PathVariable Long[] checkResultDetailIds)
    {
        return toAjax(qmsCheckResultDetailService.deleteQmsCheckResultDetailByCheckResultDetailIds(checkResultDetailIds));
    }
}
