package com.hw.qms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.qms.domain.QmsQualityInstance;
import com.hw.qms.service.IQmsQualityInstanceService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 质检工单Controller
 *
 * @author xins
 * @date 2024-01-23
 */
@RestController
@RequestMapping("/qualityinstance")
public class QmsQualityInstanceController extends BaseController
{
    @Autowired
    private IQmsQualityInstanceService qmsQualityInstanceService;

    /**
     * 查询质检工单列表
     */
    @RequiresPermissions("qms:ualityinstance:list")
    @GetMapping("/list")
    public TableDataInfo list(QmsQualityInstance qmsQualityInstance)
    {
        startPage();
        List<QmsQualityInstance> list = qmsQualityInstanceService.selectQmsQualityInstanceList(qmsQualityInstance);
        return getDataTable(list);
    }

    /**
     * 导出质检工单列表
     */
    @RequiresPermissions("qms:ualityinstance:export")
    @Log(title = "质检工单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, QmsQualityInstance qmsQualityInstance)
    {
        List<QmsQualityInstance> list = qmsQualityInstanceService.selectQmsQualityInstanceList(qmsQualityInstance);
        ExcelUtil<QmsQualityInstance> util = new ExcelUtil<QmsQualityInstance>(QmsQualityInstance.class);
        util.exportExcel(response, list, "质检工单数据");
    }

    /**
     * 获取质检工单详细信息
     */
    @RequiresPermissions("qms:ualityinstance:query")
    @GetMapping(value = "/{qualityInstanceId}")
    public AjaxResult getInfo(@PathVariable("qualityInstanceId") Long qualityInstanceId)
    {
        return success(qmsQualityInstanceService.selectQmsQualityInstanceByQualityInstanceId(qualityInstanceId));
    }

    /**
     * 新增质检工单
     */
    @RequiresPermissions("qms:ualityinstance:add")
    @Log(title = "质检工单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody QmsQualityInstance qmsQualityInstance)
    {
        return toAjax(qmsQualityInstanceService.insertQmsQualityInstance(qmsQualityInstance));
    }

    /**
     * 修改质检工单
     */
    @RequiresPermissions("qms:ualityinstance:edit")
    @Log(title = "质检工单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody QmsQualityInstance qmsQualityInstance)
    {
        return toAjax(qmsQualityInstanceService.updateQmsQualityInstance(qmsQualityInstance));
    }

    /**
     * 删除质检工单
     */
    @RequiresPermissions("qms:ualityinstance:remove")
    @Log(title = "质检工单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{qualityInstanceIds}")
    public AjaxResult remove(@PathVariable Long[] qualityInstanceIds)
    {
        return toAjax(qmsQualityInstanceService.deleteQmsQualityInstanceByQualityInstanceIds(qualityInstanceIds));
    }
}
