package com.hw.wms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.wms.domain.WmsBasePosition;
import com.hw.wms.service.IWmsBasePositionService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 位置信息Controller
 * 
 * @author xs
 * @date 2023-12-20
 */
@RestController
@RequestMapping("/wmsposition")
public class WmsBasePositionController extends BaseController
{
    @Autowired
    private IWmsBasePositionService wmsBasePositionService;

    /**
     * 查询位置信息列表
     */
    @RequiresPermissions("wms:wmsposition:list")
    @GetMapping("/list")
    public TableDataInfo list(WmsBasePosition wmsBasePosition)
    {
        startPage();
        List<WmsBasePosition> list = wmsBasePositionService.selectWmsBasePositionList(wmsBasePosition);
        return getDataTable(list);
    }

    /**
     * 导出位置信息列表
     */
    @RequiresPermissions("wms:wmsposition:export")
    @Log(title = "位置信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WmsBasePosition wmsBasePosition)
    {
        List<WmsBasePosition> list = wmsBasePositionService.selectWmsBasePositionList(wmsBasePosition);
        ExcelUtil<WmsBasePosition> util = new ExcelUtil<WmsBasePosition>(WmsBasePosition.class);
        util.exportExcel(response, list, "位置信息数据");
    }

    /**
     * 获取位置信息详细信息
     */
    @RequiresPermissions("wms:wmsposition:query")
    @GetMapping(value = "/{basePositionId}")
    public AjaxResult getInfo(@PathVariable("basePositionId") Long basePositionId)
    {
        return success(wmsBasePositionService.selectWmsBasePositionByBasePositionId(basePositionId));
    }

    /**
     * 新增位置信息
     */
    @RequiresPermissions("wms:wmsposition:add")
    @Log(title = "位置信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WmsBasePosition wmsBasePosition)
    {
        return toAjax(wmsBasePositionService.insertWmsBasePosition(wmsBasePosition));
    }

    /**
     * 修改位置信息
     */
    @RequiresPermissions("wms:wmsposition:edit")
    @Log(title = "位置信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WmsBasePosition wmsBasePosition)
    {
        return toAjax(wmsBasePositionService.updateWmsBasePosition(wmsBasePosition));
    }

    /**
     * 删除位置信息
     */
    @RequiresPermissions("wms:wmsposition:remove")
    @Log(title = "位置信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{basePositionIds}")
    public AjaxResult remove(@PathVariable Long[] basePositionIds)
    {
        return toAjax(wmsBasePositionService.deleteWmsBasePositionByBasePositionIds(basePositionIds));
    }
}
