package com.hw.wms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.wms.domain.WmsProductStockSaleorder;
import com.hw.wms.service.IWmsProductStockSaleorderService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 成品订单库存记录Controller
 * 
 * @author xins
 * @date 2024-02-22
 */
@RestController
@RequestMapping("/productstocksaleorder")
public class WmsProductStockSaleorderController extends BaseController
{
    @Autowired
    private IWmsProductStockSaleorderService wmsProductStockSaleorderService;

    /**
     * 查询成品订单库存记录列表
     */
    @RequiresPermissions("wms:productstocksaleorder:list")
    @GetMapping("/list")
    public TableDataInfo list(WmsProductStockSaleorder wmsProductStockSaleorder)
    {
        startPage();
        List<WmsProductStockSaleorder> list = wmsProductStockSaleorderService.selectWmsProductStockSaleorderList(wmsProductStockSaleorder);
        return getDataTable(list);
    }

    /**
     * 导出成品订单库存记录列表
     */
    @RequiresPermissions("wms:productstocksaleorder:export")
    @Log(title = "成品订单库存记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WmsProductStockSaleorder wmsProductStockSaleorder)
    {
        List<WmsProductStockSaleorder> list = wmsProductStockSaleorderService.selectWmsProductStockSaleorderList(wmsProductStockSaleorder);
        ExcelUtil<WmsProductStockSaleorder> util = new ExcelUtil<WmsProductStockSaleorder>(WmsProductStockSaleorder.class);
        util.exportExcel(response, list, "成品订单库存记录数据");
    }

    /**
     * 获取成品订单库存记录详细信息
     */
    @RequiresPermissions("wms:productstocksaleorder:query")
    @GetMapping(value = "/{productStockSaleorderId}")
    public AjaxResult getInfo(@PathVariable("productStockSaleorderId") Long productStockSaleorderId)
    {
        return success(wmsProductStockSaleorderService.selectWmsProductStockSaleorderByProductStockSaleorderId(productStockSaleorderId));
    }

    /**
     * 新增成品订单库存记录
     */
    @RequiresPermissions("wms:productstocksaleorder:add")
    @Log(title = "成品订单库存记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WmsProductStockSaleorder wmsProductStockSaleorder)
    {
        return toAjax(wmsProductStockSaleorderService.insertWmsProductStockSaleorder(wmsProductStockSaleorder));
    }

    /**
     * 修改成品订单库存记录
     */
    @RequiresPermissions("wms:productstocksaleorder:edit")
    @Log(title = "成品订单库存记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WmsProductStockSaleorder wmsProductStockSaleorder)
    {
        return toAjax(wmsProductStockSaleorderService.updateWmsProductStockSaleorder(wmsProductStockSaleorder));
    }

    /**
     * 删除成品订单库存记录
     */
    @RequiresPermissions("wms:productstocksaleorder:remove")
    @Log(title = "成品订单库存记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{productStockSaleorderIds}")
    public AjaxResult remove(@PathVariable Long[] productStockSaleorderIds)
    {
        return toAjax(wmsProductStockSaleorderService.deleteWmsProductStockSaleorderByProductStockSaleorderIds(productStockSaleorderIds));
    }
}
