package com.hw.wms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.wms.domain.WmsRawInstock;
import com.hw.wms.service.IWmsRawInstockService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 原材料入库记录Controller
 * 
 * @author xs
 * @date 2023-12-20
 */
@RestController
@RequestMapping("/rawinstock")
public class WmsRawInstockController extends BaseController
{
    @Autowired
    private IWmsRawInstockService wmsRawInstockService;

    /**
     * 查询原材料入库记录列表
     */
    @RequiresPermissions("wms:rawinstock:list")
    @GetMapping("/list")
    public TableDataInfo list(WmsRawInstock wmsRawInstock)
    {
        startPage();
        List<WmsRawInstock> list = wmsRawInstockService.selectWmsRawInstockList(wmsRawInstock);
        return getDataTable(list);
    }

    /**
     * 导出原材料入库记录列表
     */
    @RequiresPermissions("wms:rawinstock:export")
    @Log(title = "原材料入库记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WmsRawInstock wmsRawInstock)
    {
        List<WmsRawInstock> list = wmsRawInstockService.selectWmsRawInstockList(wmsRawInstock);
        ExcelUtil<WmsRawInstock> util = new ExcelUtil<WmsRawInstock>(WmsRawInstock.class);
        util.exportExcel(response, list, "原材料入库记录数据");
    }

    /**
     * 获取原材料入库记录详细信息
     */
    @RequiresPermissions("wms:rawinstock:query")
    @GetMapping(value = "/{rawInstockId}")
    public AjaxResult getInfo(@PathVariable("rawInstockId") Long rawInstockId)
    {
        return success(wmsRawInstockService.selectWmsRawInstockByRawInstockId(rawInstockId));
    }

    /**
     * 新增原材料入库记录
     */
    @RequiresPermissions("wms:rawinstock:add")
    @Log(title = "原材料入库记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WmsRawInstock wmsRawInstock)
    {
        return toAjax(wmsRawInstockService.insertWmsRawInstock(wmsRawInstock));
    }

    /**
     * 修改原材料入库记录
     */
    @RequiresPermissions("wms:rawinstock:edit")
    @Log(title = "原材料入库记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WmsRawInstock wmsRawInstock)
    {
        return toAjax(wmsRawInstockService.updateWmsRawInstock(wmsRawInstock));
    }

    /**
     * 删除原材料入库记录
     */
    @RequiresPermissions("wms:rawinstock:remove")
    @Log(title = "原材料入库记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{rawInstockIds}")
    public AjaxResult remove(@PathVariable Long[] rawInstockIds)
    {
        return toAjax(wmsRawInstockService.deleteWmsRawInstockByRawInstockIds(rawInstockIds));
    }
}
