package com.hw.wms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.hw.common.core.constant.WmsConstants;
import com.hw.wms.domain.WmsBaseWarehouse;
import com.hw.wms.domain.vo.WmsRawOutstockAuditVo;
import com.hw.wms.service.IWmsBaseWarehouseService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.wms.domain.WmsRawOutstock;
import com.hw.wms.service.IWmsRawOutstockService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 原材料出库记录Controller
 *
 * @author xs
 * @date 2023-12-20
 */
@RestController
@RequestMapping("/rawoutstock")
public class WmsRawOutstockController extends BaseController
{
    @Autowired
    private IWmsRawOutstockService wmsRawOutstockService;

    @Autowired
    private IWmsBaseWarehouseService wmsBaseWarehouseService;

    /**
     * 查询原材料出库记录列表
     */
    @RequiresPermissions("wms:rawoutstock:list")
    @GetMapping("/list")
    public TableDataInfo list(WmsRawOutstock wmsRawOutstock)
    {
        startPage();
        List<WmsRawOutstock> list = wmsRawOutstockService.selectWmsRawOutstockJoinList(wmsRawOutstock);
        return getDataTable(list);
    }

    /**
     * 获取仓库信息列表，提供给审核使用
     */
    @RequiresPermissions("wms:rawoutstock:list")
    @GetMapping(value = "/getWarehouses")
    public AjaxResult getWarehouses() {
        WmsBaseWarehouse queryWarehouse = new WmsBaseWarehouse();
        List<WmsBaseWarehouse> warehouses = wmsBaseWarehouseService.selectWmsBaseWarehouseList(queryWarehouse);
        return success(warehouses);
    }

    /**
     * 导出原材料出库记录列表
     */
    @RequiresPermissions("wms:rawoutstock:export")
    @Log(title = "原材料出库记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WmsRawOutstock wmsRawOutstock)
    {
        List<WmsRawOutstock> list = wmsRawOutstockService.selectWmsRawOutstockList(wmsRawOutstock);
        ExcelUtil<WmsRawOutstock> util = new ExcelUtil<WmsRawOutstock>(WmsRawOutstock.class);
        util.exportExcel(response, list, "原材料出库记录数据");
    }

    /**
     * 获取原材料出库记录详细信息
     */
    @RequiresPermissions("wms:rawoutstock:query")
    @GetMapping(value = "/{rawOutstockId}")
    public AjaxResult getInfo(@PathVariable("rawOutstockId") Long rawOutstockId)
    {
        return success(wmsRawOutstockService.selectWmsRawOutstockByRawOutstockId(rawOutstockId));
    }



    /**
     * 申请领料
     * @param wmsRawOutstock
     * @return
     */
    @Log(title = "原材料出库记录", businessType = BusinessType.APPLY)
    @PostMapping("/applyRawOutstock")
    public AjaxResult applyRawOutstock(@RequestBody WmsRawOutstock wmsRawOutstock)
    {
        return toAjax(wmsRawOutstockService.applyRawOutstock(wmsRawOutstock));
    }


    /**
     * 查询原材料出库记录列表，供审核使用
     */
    @RequiresPermissions("wms:rawoutstock:audit:list")
    @GetMapping("/auditList")
    public TableDataInfo auditList(WmsRawOutstock wmsRawOutstock)
    {
        startPage();
        List<WmsRawOutstock> list = wmsRawOutstockService.selectWmsRawOutstockJoinList4Audit(wmsRawOutstock);
        return getDataTable(list);
    }

    @RequiresPermissions("wms:rawoutstock:audit:query")
    @GetMapping(value = "/getRawOutstockByTaskCode/{taskCode}")
    public AjaxResult getRawOutstockByTaskCode(@PathVariable("taskCode") String taskCode) {
        return success(wmsRawOutstockService.selectWmsRawOutstockByTaskCode(taskCode));
    }


    /**
     * 审核原材料出库记录
     */
    @RequiresPermissions("wms:rawoutstock:audit:audit")
    @Log(title = "原材料出库记录", businessType = BusinessType.AUDIT)
    @PostMapping(("/auditRawOutstock"))
    public AjaxResult auditRawOutstock(@Validated @RequestBody WmsRawOutstockAuditVo wmsRawOutstockAuditVo) {
        return success(wmsRawOutstockService.auditWmsRawOutstock(wmsRawOutstockAuditVo));
    }


    /**
     * 获取仓库信息列表，提供给审核使用
     */
    @RequiresPermissions("wms:rawoutstock:audit:list")
    @GetMapping(value = "/getWarehouses4Audit")
    public AjaxResult getWarehouses4Audit() {
        WmsBaseWarehouse queryWarehouse = new WmsBaseWarehouse();
        List<WmsBaseWarehouse> warehouses = wmsBaseWarehouseService.selectWmsBaseWarehouseList(queryWarehouse);
        return success(warehouses);
    }
}
