package com.hw.wms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.hw.wms.domain.WmsBaseWarehouse;
import com.hw.wms.domain.vo.WmsRawOutstockAuditVo;
import com.hw.wms.domain.vo.WmsRawReturnAuditVo;
import com.hw.wms.service.IWmsBaseWarehouseService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.wms.domain.WmsRawReturn;
import com.hw.wms.service.IWmsRawReturnService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 原材料退库记录Controller
 *
 * @author xs
 * @date 2023-12-20
 */
@RestController
@RequestMapping("/rawreturn")
public class WmsRawReturnController extends BaseController
{
    @Autowired
    private IWmsRawReturnService wmsRawReturnService;

    @Autowired
    private IWmsBaseWarehouseService wmsBaseWarehouseService;

    /**
     * 查询原材料退库记录列表
     */
    @RequiresPermissions("wms:rawreturn:list")
    @GetMapping("/list")
    public TableDataInfo list(WmsRawReturn wmsRawReturn)
    {
        startPage();
        List<WmsRawReturn> list = wmsRawReturnService.selectWmsRawReturnJoinList(wmsRawReturn);
        return getDataTable(list);
    }

    /**
     * 导出原材料退库记录列表
     */
    @RequiresPermissions("wms:rawreturn:export")
    @Log(title = "原材料退库记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WmsRawReturn wmsRawReturn)
    {
        List<WmsRawReturn> list = wmsRawReturnService.selectWmsRawReturnList(wmsRawReturn);
        ExcelUtil<WmsRawReturn> util = new ExcelUtil<WmsRawReturn>(WmsRawReturn.class);
        util.exportExcel(response, list, "原材料退库记录数据");
    }

    /**
     * 获取原材料退库记录详细信息
     */
    @RequiresPermissions("wms:rawreturn:query")
    @GetMapping(value = "/{rawReturnId}")
    public AjaxResult getInfo(@PathVariable("rawReturnId") Long rawReturnId)
    {
        return success(wmsRawReturnService.selectWmsRawReturnByRawReturnId(rawReturnId));
    }


    /**
     * 获取仓库信息列表，提供给查询列表使用
     */
    @RequiresPermissions("wms:rawreturn:list")
    @GetMapping(value = "/getWarehouses")
    public AjaxResult getWarehouses() {
        WmsBaseWarehouse queryWarehouse = new WmsBaseWarehouse();
        List<WmsBaseWarehouse> warehouses = wmsBaseWarehouseService.selectWmsBaseWarehouseList(queryWarehouse);
        return success(warehouses);
    }



    /**
     * 查询原材料退库记录列表
     */
    @RequiresPermissions("wms:rawreturn:audit:list")
    @GetMapping("/auditList")
    public TableDataInfo auditList(WmsRawReturn wmsRawReturn)
    {
        startPage();
        List<WmsRawReturn> list = wmsRawReturnService.selectWmsRawReturnJoinList(wmsRawReturn);
        return getDataTable(list);
    }

    /**
     * 获取原材料退库记录详细信息
     */
    @RequiresPermissions("wms:rawreturn:audit:query")
    @GetMapping(value = "/getRawreturn4Audit/{rawReturnId}")
    public AjaxResult getRawreturn4Audit(@PathVariable("rawReturnId") Long rawReturnId)
    {
        return success(wmsRawReturnService.selectWmsRawReturnByRawReturnId(rawReturnId));
    }

    /**
     * 审核原材料退库记录
     */
    @RequiresPermissions("wms:rawreturn:audit:audit")
    @Log(title = "原材料退库记录", businessType = BusinessType.AUDIT)
    @PostMapping(("/auditRawReturn"))
    public AjaxResult auditRawReturn(@Validated @RequestBody WmsRawReturnAuditVo wmsRawReturnAuditVo) {
        return toAjax(wmsRawReturnService.auditWmsRawReturn(wmsRawReturnAuditVo));
    }

    /**
     * 获取仓库信息列表，提供给审核使用
     */
    @RequiresPermissions("wms:rawreturn:audit:list")
    @GetMapping(value = "/getWarehouses4Audit")
    public AjaxResult getWarehouses4Audit() {
        WmsBaseWarehouse queryWarehouse = new WmsBaseWarehouse();
        List<WmsBaseWarehouse> warehouses = wmsBaseWarehouseService.selectWmsBaseWarehouseList(queryWarehouse);
        return success(warehouses);
    }
}
