package com.hw.wms.service;

import java.util.List;
import com.hw.wms.domain.WmsRawInstock;
import com.hw.wms.domain.vo.WmsRawInstockVo;
import org.springframework.transaction.annotation.Transactional;

/**
 * 原材料入库记录Service接口
 *
 * @author xs
 * @date 2023-12-20
 */
public interface IWmsRawInstockService
{
    /**
     * 查询原材料入库记录
     *
     * @param rawInstockId 原材料入库记录主键
     * @return 原材料入库记录
     */
    public WmsRawInstock selectWmsRawInstockByRawInstockId(Long rawInstockId);

    /**
     * 查询原材料入库记录列表
     *
     * @param wmsRawInstock 原材料入库记录
     * @return 原材料入库记录集合
     */
    public List<WmsRawInstock> selectWmsRawInstockList(WmsRawInstock wmsRawInstock);

    /**
     * 新增原材料入库记录
     *
     * @param wmsRawInstock 原材料入库记录
     * @return 结果
     */
    public int insertWmsRawInstock(WmsRawInstock wmsRawInstock);

    /**
     * 修改原材料入库记录
     *
     * @param wmsRawInstock 原材料入库记录
     * @return 结果
     */
    public int updateWmsRawInstock(WmsRawInstock wmsRawInstock);

    /**
     * 批量删除原材料入库记录
     *
     * @param rawInstockIds 需要删除的原材料入库记录主键集合
     * @return 结果
     */
    public int deleteWmsRawInstockByRawInstockIds(Long[] rawInstockIds);

    /**
     * 删除原材料入库记录信息
     *
     * @param rawInstockId 原材料入库记录主键
     * @return 结果
     */
    public int deleteWmsRawInstockByRawInstockId(Long rawInstockId);




    /**
     * 新增原材料入库记录(适用于移动手持端)
     *
     * @param wmsRawInstockVo 原材料入库记录
     * @return 结果
     */
    public int insertWmsRawInstock(WmsRawInstockVo wmsRawInstockVo);

}
